# -*- coding: utf-8 -*-
__title__ = "text2svg"
__version__ = "0.2.0"
__summary__ = "Convert text to svg"
__uri__ = "https://github.com/naveen521kk/text2svg"
__author__ = "Naveen M K"
__license__ = "GPLv3"
